==> taxonomy_term_overview_node_count-1.0.0.tar.gz: taxonomy_term_overview_node_count/src/EventSubscriber/TaxonomyOverviewFormAlterSubscriber.php <==
<?php

namespace Drupal\taxonomy_term_overview_node_count\EventSubscriber;

use Drupal\Core\Database\Connection;
use Drupal\core_event_dispatcher\Event\Form\FormAlterEvent;
use Drupal\core_event_dispatcher\FormHookEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Event subscriber to alter the taxonomy term overview form.
 */
class TaxonomyOverviewFormAlterSubscriber implements EventSubscriberInterface {

  /**
   * The database connection used to store flood event information.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected Connection $connection;

  /**
   * Construct the TaxonomyOverviewFormAlterSubscriber.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection which will be used to store the flood event
   *    information.
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      FormHookEvents::FORM_ALTER => 'onFormAlter',
    ];
  }

  /**
   * Alters the taxonomy term overview form.
   *
   * @param \Drupal\core_event_dispatcher\Event\Form\FormAlterEvent $event
   *   The form alter event.
   */
  public function onFormAlter(FormAlterEvent $event) {
    $form_id = $event->getFormId();

    // Check if this is the taxonomy overview form.
    if (strpos($form_id, 'taxonomy_overview_terms') !== FALSE) {
      $form = &$event->getForm();
      // Add node count data for each row.
      foreach ($form['terms'] as $key => $row) {
        if (str_contains($key, 'tid:')) {
          $values = explode(":", $key);
          $term_id = $values[1];
          // Get the node count for the term.
          $node_count = $this->getNodeCountForTerm($term_id);
          // Append the node count in title.
          $form['terms'][$key]['term']["#title"] = $form['terms'][$key]['term']["#title"] . ' (' . $node_count . ')';
        }
      }
    }
  }

  /**
   * Fetches the count of nodes associated with a taxonomy term.
   *
   * @param int $term_id
   *   The taxonomy term ID.
   *
   * @return int
   *   The number of associated nodes.
   */
  protected function getNodeCountForTerm($term_id): int {
    $query = $this->connection->select('taxonomy_index', 'ti');
    $query->condition('ti.tid', $term_id);
    $query->addExpression('COUNT(ti.nid)', 'node_count');
    return (int) $query->execute()->fetchField();
  }

}

==> taxonomy_term_overview_node_count-1.0.1.tar.gz: taxonomy_term_overview_node_count/src/EventSubscriber/TaxonomyOverviewFormAlterSubscriber.php <==
<?php

namespace Drupal\taxonomy_term_overview_node_count\EventSubscriber;

use Drupal\Core\Database\Connection;
use Drupal\core_event_dispatcher\Event\Form\AbstractFormEvent;
use Drupal\core_event_dispatcher\FormHookEvents;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Event subscriber to alter the taxonomy term overview form.
 */
class TaxonomyOverviewFormAlterSubscriber implements EventSubscriberInterface {

  /**
   * The database connection used to store flood event information.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected Connection $connection;

  /**
   * Constructs a new TaxonomyOverviewFormAlterSubscriber object.
   *
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection which will be used to store the flood event
   *    information.
   */
  public function __construct(Connection $connection) {
    $this->connection = $connection;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      FormHookEvents::FORM_ALTER => 'onFormAlter',
    ];
  }

  /**
   * Alters the taxonomy term overview form.
   *
   * @param \Drupal\core_event_dispatcher\Event\Form\AbstractFormEvent $event
   *   The event.
   */
  public function onFormAlter(AbstractFormEvent $event) {
    $form_id = $event->getFormId();

    // Check if this is the taxonomy overview form.
    if (strpos($form_id, 'taxonomy_overview_terms') !== FALSE) {
      $form = &$event->getForm();
      // Add node count data for each row.
      foreach ($form['terms'] as $key => $row) {
        if (str_contains($key, 'tid:')) {
          $values = explode(":", $key);
          $term_id = $values[1];
          // Get the node count for the term.
          $node_count = $this->getNodeCountForTerm($term_id);
          // Append the node count in title.
          $form['terms'][$key]['term']["#title"] = $form['terms'][$key]['term']["#title"] . ' (' . $node_count . ')';
        }
      }
    }
  }

  /**
   * Fetches the count of nodes associated with a taxonomy term.
   *
   * @param int $term_id
   *   The taxonomy term ID.
   *
   * @return int
   *   The number of associated nodes.
   */
  protected function getNodeCountForTerm($term_id): int {
    $query = $this->connection->select('taxonomy_index', 'ti');
    $query->condition('ti.tid', $term_id);
    $query->addExpression('COUNT(ti.nid)', 'node_count');
    return (int) $query->execute()->fetchField();
  }

}
